export declare namespace Protocol {
    class InstallableServer {
        id: string;
        name: string;
        release: boolean;
        label: string;
        version: string;
        build: string;
        buildId: string;
        description: string;
        vendor: string;
        url: string;
        addedTimestamp: string;
    }
    interface InstallServerRequest {
        id: string;
        installableServerId: string;
        installationLocation: string;
    }
    interface InstallingServer {
        id: string;
        state: number;
        msg: string;
        installServerRequest: InstallServerRequest;
        installationStartedTimestamp: string;
        started: number;
    }
    interface CancelServerInstallationRequest {
        id: string;
        installingServerId: string;
    }
    interface Installation {
        id: string;
        location: string;
        installationStartedTimestamp: string;
        installationCompleteTimestamp: string;
        duration: string;
        installableServerId?: string;
    }
    interface ServerRunConfiguration {
        id: string;
        host: string;
        port: number;
        jvm: JVM;
        startTimeout: number;
        installation: Installation;
    }
    interface ServerInstanceHandle {
        id: string;
        installationId: string;
        processId: string;
        state: number;
        startedTimestamp: string;
        runConfiguration: ServerRunConfiguration;
        stoppedTimestamp?: string;
    }
    interface AnalysisRunConfiguration {
        id: string;
        clientId: string;
        name: string;
        options: {
            [index: string]: any;
        };
        serverInstanceHandleId: string;
    }
    interface Analysis {
        id: string;
        state: number;
        analysisConfiguration: AnalysisRunConfiguration;
    }
    interface Option {
        name: string;
        value: any;
    }
    interface Status {
        code: number;
        message: string;
        ok: boolean;
    }
    class JVM {
        id: string;
        name: string;
        location: string;
        version: string;
    }
    namespace ServerState {
        const UNKNOWN = 0;
        const STARTING = 1;
        const STARTED = 2;
        const RUNNING = 3;
        const STOPPING = 4;
        const STOPPED = 5;
        const ANALYZING = 6;
        const PREPARING_INSTALLATION = 7;
        const INSTALLING = 8;
        const INSTALLED = 9;
        const UNINSTALLING = 10;
        const UNINSTALLED = 11;
        const DELETING = 12;
        const DELETED = 13;
    }
}
